package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.jna.LibAndroidUsbByJNA;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.model.devices.IFrameSetting;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.model.event.FastbootEvent;
import com.vendor.burn.serial.workers.CallLibBootromWorker;
import com.vendor.burn.serial.workers.FastbootBurnerWorker;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubMonitor;
import org.eclipse.osgi.util.NLS;

public class CallLibUSBWorker extends FastbootBurnerWorker {
  private static boolean connected = false;
  
  private static long[] handle = new long[1];
  
  private static final int OPEN_SUCCESS = 0;
  
  private static final int DOWNLOAD_SUCCESS = 1;
  
  public static final int SEND_TIMEOUT = 5000;
  
  public static final int RECV_TIMEOUT = 10000;
  
  public static final int RECV_IGNORE_TIMEOUT = 1000;
  
  public static final int GET_CUR_RECEIVED_LEN = 1024;
  
  public static final int WAIT_BOOT_RUN_RECE_LEN = 512;
  
  private static SubMonitor subMonitor;
  
  public CallLibUSBWorker(IFrameSetting frameSetting, IBurner burner, SubMonitor subProgressMonitor) {
    super(frameSetting, burner);
    setSubMonitor(subProgressMonitor);
    String osName = System.getProperties().getProperty("os.name");
    if (osName.toLowerCase().startsWith("windows")) {
      System.setProperty("jna.encoding", "GBK");
    } else {
      System.setProperty("jna.encoding", "UTF-8");
    } 
  }
  
  private static void monitorCancel() {
    if (monitor != null) {
      FastbootEvent event = monitor.getEvent();
      if (event != null) {
        event.setUserCanceled(true);
        event.setSuccess(false);
        event.setMessage("User Cancelled!");
      } 
    } 
  }
  
  public static boolean openUsb(IProgressMonitor uimonitor, long timeout, TransferWay transferWay, String serialNumber) {
    if (transferWay == TransferWay.UsbAndSerial || FastbootView.isSupportUsbNonNude(transferWay) || 
      FastbootView.isSupportUsbBootrom(transferWay)) {
      LibAndroidUsbByJNA.instance.RegisterPrint(CALL_FASTBOOT_BACK_CALLBACK);
      LibAndroidUsbByJNA.instance.RegisterCancel(CALL_FASTBOOT_BACK_CANCEL);
    } 
    long startTime = System.currentTimeMillis();
    int openResult = 1;
    while (System.currentTimeMillis() - startTime < timeout) {
      if (!connected) {
        if (uimonitor.isCanceled()) {
          monitorCancel();
          return false;
        } 
        if (FastbootView.isSupportUsbBootrom(transferWay)) {
          openResult = LibAndroidUsbByJNA.instance.OpenUsb(handle, UnknownDevice.getUsbVid(), 
              UnknownDevice.getUsbPid(), BurnConfig.getUsbDeviceName());
        } else if (transferWay == TransferWay.UsbAndSerial || FastbootView.isSupportUsbNonNude(transferWay)) {
          int isExistsSerial = 0;
          if (ToolUtils.isCmdLine() && transferWay == TransferWay.UsbAndSerial) {
            isExistsSerial = 1;
          } else {
            serialNumber = null;
          } 
          openResult = LibAndroidUsbByJNA.instance.USB_Open(handle, isExistsSerial, serialNumber);
          if (openResult != 0)
            return checkReturn(monitor, openResult); 
        } else if (CallLibBootromWorker.openUsbDevice(UnknownDevice.getUsbVid(), UnknownDevice.getUsbPid(), 
            BurnConfig.getUsbDeviceName())) {
          handle[0] = CallLibBootromWorker.getUsbFd();
          openResult = 0;
        } 
        if (openResult == 0) {
          System.out.println("Open USB Success");
          connected = true;
          return true;
        } 
        continue;
      } 
      return true;
    } 
    return false;
  }
  
  public static void closeUsb(TransferWay transferWay) {
    if (connected) {
      if (transferWay == TransferWay.UsbAndSerial || 
        FastbootView.isSupportUsbNonNude(transferWay) || 
        FastbootView.isSupportUsbBootrom(transferWay)) {
        LibAndroidUsbByJNA.instance.USB_Close(handle[0]);
      } else {
        CallLibBootromWorker.destroyDevice(handle[0]);
      } 
      connected = false;
    } 
  }
  
  public static boolean sendDataByUsb(byte[] pData, int nLen, TransferWay transferWay) {
    if (connected) {
      int sendLen = -1;
      boolean isAndroidUsb = (transferWay == TransferWay.UsbAndSerial || (FastbootView.isChipBranchSeries4() && transferWay == TransferWay.USBNonNude) || FastbootView.isSupportUsbBootrom(transferWay));
      if (isAndroidUsb) {
        sendLen = LibAndroidUsbByJNA.instance.USB_SendData(handle[0], pData, nLen, 5000);
        if (sendLen == nLen)
          return true; 
      } else if (CallLibBootromWorker.sendBytes(handle[0], pData, nLen)) {
        return true;
      } 
    } 
    return false;
  }
  
  public static boolean recvDataUsb(byte[] pData, int nLen, TransferWay transferWay) {
    if (connected) {
      int recvLen = -1;
      if (transferWay == TransferWay.UsbAndSerial || 
        FastbootView.isSupportUsbNonNude(transferWay) || 
        FastbootView.isSupportUsbBootrom(transferWay) || transferWay == TransferWay.GPT) {
        recvLen = LibAndroidUsbByJNA.instance.USB_RecvData(handle[0], pData, nLen, 5000);
        if (recvLen == nLen)
          return true; 
      } else if (CallLibBootromWorker.recevieBytes(handle[0], pData, nLen)) {
        return true;
      } 
    } 
    return false;
  }
  
  public static void recvDataUsbIgnore(byte[] pData, int nLen, TransferWay transferWay) {
    if (connected)
      if (transferWay == TransferWay.UsbAndSerial || 
        FastbootView.isSupportUsbNonNude(transferWay) || 
        FastbootView.isSupportUsbBootrom(transferWay)) {
        LibAndroidUsbByJNA.instance.USB_RecvData(handle[0], pData, nLen, 10000);
      } else {
        CallLibBootromWorker.recevieBytes(handle[0], pData, nLen);
      }  
  }
  
  public static boolean downloadFileGptByUsb(File file) {
    String filePath = file.getPath();
    if (connected) {
      int downloadResult = LibAndroidUsbByJNA.instance.USB_DownloadFileGpt(handle[0], filePath);
      if (downloadResult == 1)
        return true; 
      return false;
    } 
    return false;
  }
  
  public static boolean downloadFileByUsb(File file, int ddrAddress, TransferWay transferWay) {
    String filePath = file.getPath();
    if (connected) {
      int downloadResult = -1;
      if (transferWay == TransferWay.UsbAndSerial || 
        FastbootView.isSupportUsbNonNude(transferWay) || 
        FastbootView.isSupportUsbBootrom(transferWay)) {
        downloadResult = LibAndroidUsbByJNA.instance.USB_DownloadFile(handle[0], filePath, ddrAddress);
        if (downloadResult == 1)
          return true; 
      } else if (CallLibBootromWorker.downloadData(handle[0], filePath, ddrAddress)) {
        return true;
      } 
    } 
    return false;
  }
  
  public static boolean uploadFileByUsb(File file, int ddrAddress, int length, TransferWay transferWay) {
    String filePath = file.getPath();
    if (connected) {
      int downloadResult = 0;
      if (transferWay == TransferWay.UsbAndSerial || 
        FastbootView.isSupportUsbNonNude(transferWay) || 
        FastbootView.isSupportUsbBootrom(transferWay)) {
        downloadResult = LibAndroidUsbByJNA.instance.USB_UploadFile(handle[0], filePath, ddrAddress, length);
        if (downloadResult == 1)
          return true; 
      } else if (CallLibBootromWorker.uploadFileByUsbTftp(handle[0], filePath)) {
        return true;
      } 
    } 
    return false;
  }
  
  public static boolean eraseGptPartByUSB(String partitonName, int timeout) {
    if (connected) {
      int downloadResult = LibAndroidUsbByJNA.instance.USB_EraseGptPartiton(handle[0], partitonName, timeout);
      if (downloadResult == 1)
        return true; 
      return false;
    } 
    return false;
  }
  
  public static boolean eraseFlashByUSB(int ddrAddress, int length, int timeout) {
    if (connected) {
      int downloadResult = LibAndroidUsbByJNA.instance.USB_EraseFlash(handle[0], ddrAddress, length, timeout);
      if (downloadResult == 1)
        return true; 
      return false;
    } 
    return false;
  }
  
  public static final LibAndroidUsbByJNA.JavaCallbackCancel CALL_FASTBOOT_BACK_CANCEL = (LibAndroidUsbByJNA.JavaCallbackCancel)new Object();
  
  public static final LibAndroidUsbByJNA.JavaCallbackAdd CALL_FASTBOOT_BACK_CALLBACK = (LibAndroidUsbByJNA.JavaCallbackAdd)new Object();
  
  public static boolean isConnected() {
    return connected;
  }
  
  public static boolean checkReturn(IFastbootProgressMonitor monitor, int input) {
    boolean result = false;
    LibUsbEnum returnValue = LibUsbEnum.valueOf(input);
    if (returnValue == null)
      return result; 
    switch (null.$SwitchMap$com$vendor$burn$serial$workers$CallLibUSBWorker$LibUsbEnum[returnValue.ordinal()]) {
      case 1:
        result = true;
        break;
      case 2:
        monitor.getEvent().setMessage(Messages.ERROR_USB_OPEN_TIMEOUT);
        break;
      case 3:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_IO.name()));
        break;
      case 4:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_INVALID_PARAM.name()));
        break;
      case 5:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_ACCESS.name()));
        break;
      case 6:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_NO_DEVICE.name()));
        break;
      case 7:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_NOT_FOUND.name()));
        break;
      case 8:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_BUSY.name()));
        break;
      case 9:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_TIMEOUT.name()));
        break;
      case 10:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_OVERFLOW.name()));
        break;
      case 11:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_PIPE.name()));
        break;
      case 12:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_INTERRUPTED.name()));
        break;
      case 13:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_NO_MEM.name()));
        break;
      case 14:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_NOT_SUPPORTED.name()));
        break;
      case 15:
        monitor.getEvent().setMessage(
            NLS.bind(Messages.ERROR_USB_OPEN_FAILED, LibUsbEnum.LIBUSB_ERROR_OTHER.name()));
        break;
    } 
    return result;
  }
  
  public static <T> LibUsbEnum getEnum(int index) {
    Class<LibUsbEnum> clazz = LibUsbEnum.class;
    T[] c = (T[])clazz.getEnumConstants();
    return (LibUsbEnum)c[index];
  }
  
  public static SubMonitor getSubMonitor() {
    return subMonitor;
  }
  
  public static void setSubMonitor(SubMonitor subMonitor) {
    com.vendor.burn.serial.workers.CallLibUSBWorker.subMonitor = subMonitor;
  }
}
